@@ -16,9 +16,7 @@ def build_service(client_secrets_path):
         scope='https://www.googleapis.com/auth/androidpublisher')
 
     # fix google's shitty algorithm of calculating timeout of the http driver to make sure the apk uploaded successfully
-    for key, val in service._http.connections.items():
-        val.sock.settimeout(260)
-
+    service._http.timeout = 300
     return service
 
 
